package org.ids_mannheim;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.*;

class UtilsTest {

    @org.junit.jupiter.api.BeforeEach
    void setUp() {
    }

    @Test
    void randomFoldIsDeterministic() {
        DeterministicRandomProvider drp = new DeterministicRandomProvider(100);
        assertEquals(89, drp.getFoldFromTextID("RPO05_JAN.00001"));
        assertEquals(47, drp.getFoldFromTextID("RPO05_JAN.00002"));
        assertEquals(0, drp.getFoldFromTextID("RPO05_JAN.00003"));
        assertEquals(91, drp.getFoldFromTextID("RPO05_JAN.00010"));
        assertEquals(53, drp.getFoldFromTextID("RPO05_JUN.00001"));
        assertEquals(94, drp.getFoldFromTextID("RPO05_JUN.00002"));
    }

    @Test
    void unEscapeEntitiesWorks() {
        assertEquals("\'\"&<>\"\'", Utils.unEscapeEntities("&apos;&quot;&amp;&lt;&gt;&quot;&apos;"));
    }

    @Test
    void fixEscapedConlluEntitiesWorks() {
        assertEquals("1\t\'\t\"\t$(\txxx", Utils.fixEscapedConlluEntities("1\t&apos;\t--\tNN\txxx"));
        assertEquals("22\t\"\t\"\t$(\txxx", Utils.fixEscapedConlluEntities("22\t&quot;\t--\tNN\txxx"));
        assertEquals("333\t<\t&lt;\t$(\txxx", Utils.fixEscapedConlluEntities("333\t&lt;\t--\tNN\txxx"));
        assertEquals("4444\t>\t&gt;\t$(\txxx", Utils.fixEscapedConlluEntities("4444\t&gt;\t--\tNN\txxx"));
        assertEquals("55555\t&\t&amp;\tKON\txxx", Utils.fixEscapedConlluEntities("55555\t&amp;\t--\tNN\txxx"));
    }

    @Test
    void isPunctuation() {
        assert(Utils.isPunctuation(",", ",", "$,"));
        assert(Utils.isPunctuation(".", ".", "$."));
        assert(Utils.isPunctuation("'", "\"", "$("));
        assert(! Utils.isPunctuation("in'", "in", "APPR"));
    }
}